@@ -1,12 +1,12 @@
 use anyhow::Result;
 use std::fs::File;
 use std::io::Write;
-use tempdir::TempDir;
+use tempfile::TempDir;
 
 pub fn create_test_files<'a>(
   names_and_contents: impl IntoIterator<Item = (&'a str, &'a str)>,
 ) -> Result<TempDir> {
-  let dir = TempDir::new("sgtest")?;
+  let dir = TempDir::new()?;
   for (name, contents) in names_and_contents {
     if let Some((sub, _)) = name.split_once('/') {
       let sub_dir = dir.path().join(sub);
