@@ -42,7 +42,7 @@ pub struct SgNode {
 impl SgNode {
   fn to_pos(&self, pos: Position, offset: usize) -> Pos {
     Pos {
-      line: pos.row() as u32,
+      line: pos.line() as u32,
       column: pos.column(&self.inner) as u32,
       index: offset as u32 / 2,
     }
@@ -79,6 +79,15 @@ impl SgNode {
   pub fn kind(&self) -> String {
     self.inner.kind().to_string()
   }
+  #[napi(getter)]
+  pub fn kind_to_refine(&self) -> String {
+    self.inner.kind().to_string()
+  }
+  /// Check if the node is the same kind as the given `kind` string
+  #[napi]
+  pub fn is(&self, kind: String) -> bool {
+    self.inner.kind() == kind
+  }
   #[napi]
   pub fn text(&self) -> String {
     self.inner.text().to_string()
@@ -258,7 +267,7 @@ impl SgNode {
     Ok(ret)
   }
 
-  /// Finds the child node in the `field`
+  /// Finds the first child node in the `field`
   #[napi]
   pub fn field(
     &self,
@@ -270,6 +279,18 @@ impl SgNode {
     Self::transpose_option(reference, env, node)
   }
 
+  /// Finds all the children nodes in the `field`
+  #[napi]
+  pub fn field_children(
+    &self,
+    reference: Reference<SgNode>,
+    env: Env,
+    name: String,
+  ) -> Result<Vec<SgNode>> {
+    let children = reference.inner.field_children(&name).map(NodeMatch::from);
+    Self::from_iter_to_vec(&reference, env, children)
+  }
+
   #[napi]
   pub fn parent(&self, reference: Reference<SgNode>, env: Env) -> Result<Option<SgNode>> {
     let node = reference.inner.parent().map(NodeMatch::from);
